==> wiki3_4_4.zip: wiki3_4_4/plugin/partedit/PartEdit.pm <==
############################################################
#
# ФԽǤ褦ˤޤ
# <pre>
# {{partedit}}
# </pre>
#
############################################################
package plugin::partedit::PartEdit;
#use strict;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
  my $class = shift;
  my $self = {};
  return bless $self,$class;
}

#===========================================================
# ԽʬμФ
#===========================================================
sub read_by_part {
    my $page = shift;
  
    my @lines = map { $_."\n" } split(/\x0D\x0A|\x0D|\x0A/, $page);
    my @parts = ('');
    foreach my $line (@lines) {
        if ($line =~ /^\!{1,2}[^\*]/) { push @parts, $line; }
        else                          { $parts[$#parts] .= $line; }
    }
    return @parts;
}

#===========================================================
# μ¹
#===========================================================
sub do_action {
	my $self = shift;
	my $wiki = shift;
	my $cgi = $wiki->get_CGI;

	my $pagename = $cgi->param("page");
	my $artno    = $cgi->param("artno");
	my $content  = $cgi->param("content");
	my $template = $cgi->param("template");
	my $time     = $wiki->get_last_modified($pagename);
	
	my $buf = "";
	my $login = $wiki->get_login_info();
	if($pagename eq ""){
		return $wiki->error("ڡꤵƤޤ!!");
	}
	if(!$wiki->can_modify_page($pagename)){
		return $wiki->error("ڡԽϵĤƤޤ");
	}
	
	#---------------------------------------------------------------
	# ¸
	if($cgi->param("save") ne ""){
		if($wiki->page_exists($pagename)){
			if($cgi->param("lastmodified") < $time){
				return $wiki->error("ڡϴ̤Υ桼ˤäƹƤޤ");
			}
		}
		my @parts = &read_by_part($wiki->get_page($pagename));
		$content =~ s/\x0D\x0A|\x0D|\x0A/\n/g;
		$content .= "\n" unless ($content =~ /\n$/);
		$parts[$artno+1] = $content ;
		my $wcontent = join('', @parts);
		if($pagename eq "FrontPage" && $wcontent eq ""){
			$buf = "<b>FrontPageϺ뤳ȤϤǤޤ</b>\n";
		} else {
			$wiki->save_page($pagename,$wcontent);
			if($content ne "\n"){
				$wiki->redirect($pagename);
			} else {
				$wiki->set_title($pagename."ޤ");
				return $cgi->escapeHTML($pagename)."ΥѡȤޤ";
			}
		}
	#---------------------------------------------------------------
	# ץӥ塼
	} elsif($cgi->param("preview") ne ""){
		$time = $cgi->param("lastmodified");
		$buf = "ʲΥץӥ塼ǧƤС¸ץܥ򲡤Ƥ<br>";
		if($content eq ""){
			if($pagename eq "FrontPage"){
				$buf = $buf."<b>FrontPageϺ뤳ȤϤǤޤ󡣡</b>";
			} else {
				$buf = $buf."<b>ʥڡƤ϶ǤȤΥѡȤϺޤ</b>";
			}
		}
		$buf = $buf."<br>".$wiki->process_wiki($content);
		
	} elsif($wiki->page_exists($pagename)) {
		#ڡ¸ߤ
		$content = (&read_by_part($wiki->get_page($pagename)))[$artno+1];
	} elsif($template ne ""){
		#ƥץ졼Ȥꤵ줿
		$content = $wiki->get_page($template);
	}
	
	#---------------------------------------------------------------
	# ϥե
	$wiki->set_title($pagename."ΥѡԽ",1);
	$buf = $buf."<form method=\"post\" action=\"".$wiki->config('script_name')."\">\n".
	            "  <textarea cols=\"80\" rows=\"20\" name=\"content\">".$cgi->escapeHTML($content)."</textarea><br>\n".
	            "  <input type=\"submit\" name=\"save\" value=\"  ¸ \">\n".
	            "  <input type=\"submit\" name=\"preview\" value=\"ץӥ塼\">\n".
	            "  <input type=\"hidden\" name=\"action\" value=\"PARTEDIT\">\n".
	            "  <input type=\"hidden\" name=\"lastmodified\" value=\"".Util::escapeHTML($time)."\">\n".
	            "  <input type=\"hidden\" name=\"page\" value=\"".$cgi->escapeHTML($pagename)."\">\n".
	            "  <input type=\"hidden\" name=\"artno\" value=".$artno.">\n".
	            "</form>\n";
	
	# ץ饰
	$buf .= $wiki->get_editform_plugin();
	
	return $buf;
}

1;

==> wiki3_5_0.zip: wiki3_5_0/plugin/partedit/PartEdit.pm <==
############################################################
#
# ФԽǤ褦ˤޤ
# <pre>
# {{partedit}}
# </pre>
#
############################################################
package plugin::partedit::PartEdit;
#use strict;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
  my $class = shift;
  my $self = {};
  return bless $self,$class;
}

#===========================================================
# ԽʬμФ
#===========================================================
sub read_by_part {
    my $page = shift;
  
    my @lines = map { $_."\n" } split(/\x0D\x0A|\x0D|\x0A/, $page);
    my @parts = ('');
    foreach my $line (@lines) {
        if ($line =~ /^\!{1,2}[^\*]/) { push @parts, $line; }
        else                          { $parts[$#parts] .= $line; }
    }
    return @parts;
}

#===========================================================
# μ¹
#===========================================================
sub do_action {
	my $self = shift;
	my $wiki = shift;
	my $cgi = $wiki->get_CGI;

	my $pagename = $cgi->param("page");
	my $artno = $cgi->param("artno");
	my $content  = $cgi->param("content");
	my $template = $cgi->param("template");
	my $time     = $wiki->get_last_modified($pagename);
	
	my $buf = "";
	my $login = $wiki->get_login_info();
	if($pagename eq ""){
		return $wiki->error("ڡꤵƤޤ!!");
	}
	if(!$wiki->can_modify_page($pagename)){
		return $wiki->error("ڡԽϵĤƤޤ");
	}
	
	#---------------------------------------------------------------
	# ¸
	if($cgi->param("save") ne ""){
		if($wiki->page_exists($pagename)){
			if($cgi->param("lastmodified") < $time){
				return $wiki->error("ڡϴ̤Υ桼ˤäƹƤޤ");
			}
		}
        my @parts = &read_by_part($wiki->get_page($pagename));
        $content =~ s/\x0D\x0A|\x0D|\x0A/\n/g;
        $content .= "\n" unless ($content =~ /\n$/);
        $parts[$artno+1] = $content ;
        my $wcontent = join('', @parts);
		if($pagename eq "FrontPage" && $wcontent eq ""){
			$buf = "<b>FrontPageϺ뤳ȤϤǤޤ</b>\n";
		} else {
			$wiki->save_page($pagename,$wcontent);
			if($content ne "\n"){
				$wiki->redirect($pagename);
			} else {
				$wiki->set_title($pagename."ޤ");
				return $cgi->escapeHTML($pagename)."ΥѡȤޤ";
			}
		}
	#---------------------------------------------------------------
	# ץӥ塼
	} elsif($cgi->param("preview") ne ""){
		$time = $cgi->param("lastmodified");
		$buf = "ʲΥץӥ塼ǧƤС¸ץܥ򲡤Ƥ<br>";
		if($content eq ""){
			if($pagename eq "FrontPage"){
				$buf = $buf."<b>FrontPageϺ뤳ȤϤǤޤ󡣡</b>";
			} else {
				$buf = $buf."<b>ʥڡƤ϶ǤȤΥѡȤϺޤ</b>";
			}
		}
		$buf = $buf."<br>".$wiki->process_wiki($content);

	} elsif($wiki->page_exists($pagename)) {
		#ڡ¸ߤ
        $content = (&read_by_part($wiki->get_page($pagename)))[$artno+1];
	} elsif($template ne ""){
		#ƥץ졼Ȥꤵ줿
		$content = $wiki->get_page($template);
	}
	
	#---------------------------------------------------------------
	# ϥե
	$wiki->set_title($pagename."ΥѡԽ",1);
	$buf = $buf."<form method=\"post\" action=\"$main::script_name\">\n".
	            "<textarea cols=\"80\" rows=\"20\" name=\"content\">".
	            $cgi->escapeHTML($content)."</textarea><br>\n".
	            "<input type=\"submit\" name=\"save\" value=\"  ¸ \">\n".
	            "<input type=\"submit\" name=\"preview\" value=\"ץӥ塼\">\n".
	            "<input type=\"hidden\" name=\"action\" value=\"PARTEDIT\">\n".
	            "<input type=\"hidden\" name=\"lastmodified\" value=\"".Util::escapeHTML($time)."\">\n".
	            "<input type=\"hidden\" name=\"page\" value=\"".$cgi->escapeHTML($pagename)."\">\n".
	            "<input type=\"hidden\" name=\"artno\" value=".$artno.">\n".
	            "</form>\n";
	
	# ץ饰
	$buf .= $wiki->get_editform_plugin();
	
	return $buf;
}

1;
